package be.iminds.ilabt.jfed.experimenter_gui.dialogs;

import be.iminds.ilabt.jfed.experimenter_gui.ui.AbstractDialogFactory;
import be.iminds.ilabt.jfed.fedmon.webapi.service.json.Testbed;
import javafx.fxml.FXMLLoader;
import javafx.stage.Stage;
import javafx.util.Pair;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;
import java.net.URL;
import java.time.Instant;
import java.util.Objects;

@Singleton
public class GDPRDialogFactory {
    private final AbstractDialogFactory dialogFactory;

    @Inject
    public GDPRDialogFactory(Provider<FXMLLoader> loaderProvider,
                             @Named("parentStage") Provider<Stage> parentStageProvider) {
        this.dialogFactory = new AbstractDialogFactory(loaderProvider, parentStageProvider) {
            @Override
            protected String getTitle() {
                return "Terms & Conditions";
            }

            @Override
            protected URL getFxmlLocation() {
                return GDPRDialogFactory.class.getResource("GDPRDialog.fxml");
            }
        };
    }

    /**
     * @param testbed
     * @return if the T&C is accepted, returns true + optionally a date until when
     *         if the T&C is declined, returns false + null
     *         if T&C acceptance is unknown, returns null + null
     */
    @Nonnull
    public Pair<Boolean, Instant> showDialog(@Nonnull Testbed testbed) {
        AbstractDialogFactory.StageAndController stageAndController = this.dialogFactory.createStage();
        GDPRDialog controller = (GDPRDialog)stageAndController.getController();
        controller.setTestbed(testbed);

        stageAndController.getStage().showAndWait();

        Boolean resBool = controller.hasApproved();
        if (resBool == null && Objects.equals(controller.hasDeclined(), Boolean.TRUE))
            resBool = false;
        return new Pair<Boolean, Instant>(resBool, controller.getApprovedUntil());
    }
}
